@@ -3,7 +3,7 @@
 # Base subroutines brought by the the Project-Builder project
 # which can be easily used by whatever perl project
 #
-# Copyright B. Cornec 2007-2016
+# Copyright B. Cornec 2007-today
 # Eric Anderson's changes are (c) Copyright 2012 Hewlett Packard
 # Provided under the GPL v2
 #
@@ -14,7 +14,7 @@ package ProjectBuilder::Base;
 
 use strict;
 use lib qw (lib);
-use Carp qw/confess cluck/;
+use Carp qw/confess croak/;
 use Cwd;
 use File::Path;
 use Data::Dumper;
@@ -25,7 +25,7 @@ use ProjectBuilder::Version;
 
 # Inherit from the "Exporter" module which handles exporting functions.
  
-use vars qw($VERSION $REVISION @ISA @EXPORT);
+use vars qw(@ISA @EXPORT);
 use Exporter;
  
 # Export, by default, all the functions into the namespace of
@@ -39,8 +39,7 @@ our $pbdisplaytype = "text";
 our $pblocale = "C";
 
 our @ISA = qw(Exporter);
-our @EXPORT = qw(pb_mkdir_p pb_system pb_rm_rf pb_get_date pb_log pb_log_init pb_get_uri pb_get_content pb_set_content pb_display_file pb_syntax_init pb_syntax pb_temp_init pb_get_arch pb_get_osrelease pb_check_requirements pb_check_req pb_path_expand pb_exit $pbdebug $pbLOG $pbdisplaytype $pblocale);
-($VERSION,$REVISION) = pb_version_init();
+our @EXPORT = qw(pb_mkdir_p pb_system pb_rm_rf pb_get_date pb_log pb_log_init pb_get_uri pb_get_content pb_set_content pb_display_file pb_syntax_init pb_syntax pb_temp_init pb_get_arch pb_get_osrelease pb_check_requirements pb_check_req pb_path_expand pb_path_nbfiles pb_exit $pbdebug $pbLOG $pbdisplaytype $pblocale);
 
 =pod
 
@@ -150,6 +149,8 @@ my $redir = "";
 
 pb_log(0,"$cmt... ") if ((! defined $verbose) || ($verbose ne "quiet"));
 pb_log(1,"Executing $cmd\n");
+
+croak('Please call pb_temp_init in your code before using pb_system') if (not defined "$ENV{'PBTMP'}");
 unlink("$ENV{'PBTMP'}/system.$$.log") if (-f "$ENV{'PBTMP'}/system.$$.log");
 $redir = "2>> $ENV{'PBTMP'}/system.$$.log 1>> $ENV{'PBTMP'}/system.$$.log" if ((! defined $verbose) || ($verbose ne "noredir"));
 
@@ -577,7 +578,7 @@ return($found);
 
 =item B<pb_path_expand>
 
-Expand out a path by environment variables as ($ENV{XXX}) and ~
+Expand out a path by environment variables as ($ENV{'ENVVAR'}) and ~
 
 =cut
 
@@ -586,11 +587,32 @@ sub pb_path_expand {
 my $path = shift;
 
 eval { $path =~ s/(\$ENV.+\})/$1/eeg; };
-$path =~ s/^\~/$ENV{HOME}/;
+$path =~ s/^\~/$ENV{'HOME'}/;
 
 return($path);
 }
 
+=item B<pb_path_nbfiles>
+
+Return the number of files in a directory
+
+=cut
+
+sub pb_path_nbfiles {
+
+my $path = shift;
+my $nb = 0;
+
+opendir(DIR,$path) || confess "Unable to open directory $path: $!";
+foreach my $f (readdir(DIR)) {
+	next if ($f =~ /^\.[\.]*$/);
+	$nb++;
+}
+closedir(DIR);
+
+return($nb);
+}
+
 =back 
 
 =head1 WEB SITES
