@@ -7,7 +7,7 @@
 #
 # $Id$
 #
-# Copyright B. Cornec 2007-2016
+# Copyright B. Cornec 2007-today
 # Eric Anderson's changes are (c) Copyright 2012 Hewlett Packard
 # Provided under the GPL v2
 
@@ -28,21 +28,21 @@ use ProjectBuilder::Conf;
 
 # Inherit from the "Exporter" module which handles exporting functions.
  
-use vars qw($VERSION $REVISION @ISA @EXPORT);
+use vars qw(@ISA @EXPORT);
 use Exporter;
  
 # Export, by default, all the functions into the namespace of
 # any code which uses this module.
  
 our @ISA = qw(Exporter);
-our @EXPORT = qw(pb_vcs_export pb_vcs_get_uri pb_vcs_copy pb_vcs_checkout pb_vcs_up pb_vcs_checkin pb_vcs_isdiff pb_vcs_add pb_vcs_add_if_not_in pb_vcs_cmd pb_vcs_compliant);
-($VERSION,$REVISION) = pb_version_init();
+our @EXPORT = qw(pb_vcs_init pb_vcs_export pb_vcs_get_uri pb_vcs_copy pb_vcs_checkout pb_vcs_up pb_vcs_checkin pb_vcs_isdiff pb_vcs_add pb_vcs_add_if_not_in pb_vcs_cmd pb_vcs_compliant pb_vcs_conf_update_v0);
+our ($VERSION,$REVISION,$PBCONFVER) = pb_version_init();
 
 =pod
 
 =head1 NAME
 
-ProjectBuilder::VCS, part of the project-builder.org
+ProjectBuilder::VCS, part of project-builder.org
 
 =head1 DESCRIPTION
 
@@ -52,6 +52,112 @@ This modules provides version control system functions.
 
 =over 4
 
+
+=item B<pb_vcs_init>
+
+This function setup the environment for the VCS system related to the URL given by the pbprojurl configuration parameter.
+The potential parameter indicates whether we should inititate the context or not.
+It sets up environement variables (PBPROJDIR, PBDIR, PBREVISION, PBCMSLOGFILE) 
+
+=cut
+
+sub pb_vcs_init {
+
+my $pbinit = shift;
+my $param = shift;
+
+my ($pbprojurl) = pb_conf_get("pbprojurl");
+confess "Undefined pbprojurl for $ENV{'PBPROJ'}\n" if ((not defined $pbprojurl) or (not defined $pbprojurl->{$ENV{'PBPROJ'}}));
+pb_log(2,"DEBUG: Project URL of $ENV{'PBPROJ'}: $pbprojurl->{$ENV{'PBPROJ'}}\n");
+my ($scheme, $account, $host, $port, $path) = pb_get_uri($pbprojurl->{$ENV{'PBPROJ'}});
+my $vcscmd = pb_vcs_cmd($scheme);
+
+my ($pbprojdir) = pb_conf_get_if("pbprojdir");
+
+if ((defined $pbprojdir) && (defined $pbprojdir->{$ENV{'PBPROJ'}})) {
+	$ENV{'PBPROJDIR'} = $pbprojdir->{$ENV{'PBPROJ'}};
+} else {
+	$ENV{'PBPROJDIR'} = "$ENV{'PBDEFDIR'}/$ENV{'PBPROJ'}";
+}
+# Expand potential env variable in it to allow string replacement
+eval { $ENV{'PBPROJDIR'} =~ s/(\$ENV.+\})/$1/eeg };
+
+
+# Computing the default dir for PBDIR.
+# what we have is PBPROJDIR so work from that.
+# Tree identical between PBCONFDIR and PBROOTDIR on one side and
+# PBPROJDIR and PBDIR on the other side.
+
+my $tmp = $ENV{'PBROOTDIR'};
+$tmp =~ s|^$ENV{'PBCONFDIR'}/||;
+# If no subdir, then replace again
+$tmp =~ s|^$ENV{'PBCONFDIR'}||;
+
+#
+# Check project cms compliance
+#
+my $turl = "$pbprojurl->{$ENV{'PBPROJ'}}/$tmp";
+$turl = $pbprojurl->{$ENV{'PBPROJ'}} if ($scheme =~ /^(flat)|(ftp)|(http)|(https)|(file)|(git)\b/o);
+# git svn is like svn
+$turl = "$pbprojurl->{$ENV{'PBPROJ'}}/$tmp"  if ($scheme =~ /^git\+svn/o);
+pb_vcs_compliant(undef,'PBDIR',"$ENV{'PBPROJDIR'}/$tmp",$turl,$pbinit);
+
+
+if ($scheme =~ /^hg/) {
+	$tmp = `(cd "$ENV{'PBDIR'}" ; $vcscmd identify )`;
+	chomp($tmp);
+	$tmp =~ s/^.* //;
+	$ENV{'PBREVISION'}=$tmp;
+	$ENV{'PBCMSLOGFILE'}="hg.log";
+} elsif ($scheme =~ /^git/) {
+	if ($scheme =~ /svn/) {
+		$tmp = `(cd "$ENV{'PBDIR'}" ; LANGUAGE=C $vcscmd info | grep -E '^Revision:' | cut -d: -f2)`;
+		$tmp =~ s/\s+//;
+	} else {
+		$tmp = `(cd "$ENV{'PBDIR'}" ; $vcscmd log | head -1 | cut -f2)`;
+		$tmp =~ s/^.* //;
+		# Reduce length of commit id to 8 digit
+		$tmp = substr($tmp,1,8);
+	}
+	chomp($tmp);
+	$ENV{'PBREVISION'}=$tmp;
+	$ENV{'PBCMSLOGFILE'}="git.log";
+} elsif ($scheme =~ /^(flat)|(ftp)|(http)|(https)|(file)\b/o) {
+	$ENV{'PBREVISION'}="flat";
+	$ENV{'PBCMSLOGFILE'}="flat.log";
+} elsif ($scheme =~ /^svn/) {
+	# svnversion more precise than svn info if sbx
+	if ((defined $param) && ($param eq "CMS")) {
+		$tmp = `(LANGUAGE=C $vcscmd info $pbprojurl->{$ENV{'PBPROJ'}} | grep -E '^Revision:' | cut -d: -f2)`;
+		$tmp =~ s/\s+//;
+	} else {
+		$tmp = `(cd "$ENV{'PBDIR'}" ; $vcscmd"version" .)`;
+	}
+	chomp($tmp);
+	$ENV{'PBREVISION'}=$tmp;
+	$ENV{'PBCMSLOGFILE'}="svn.log";
+} elsif ($scheme =~ /^svk/) {
+	$tmp = `(cd "$ENV{'PBDIR'}" ; LANGUAGE=C $vcscmd info . | grep -E '^Revision:' | cut -d: -f2)`;
+	$tmp =~ s/\s+//;
+	chomp($tmp);
+	$ENV{'PBREVISION'}=$tmp;
+	$ENV{'PBCMSLOGFILE'}="svk.log";
+} elsif ($scheme =~ /^cvs/) {
+	# Way too slow
+	#$ENV{'PBREVISION'}=`(cd "$ENV{'PBROOTDIR'}" ; cvs rannotate  -f . 2>&1 | awk '{print \$1}' | grep -E '^[0-9]' | cut -d. -f2 |sort -nu | tail -1)`;
+	#chomp($ENV{'PBREVISION'});
+	$ENV{'PBREVISION'}="cvs";
+	$ENV{'PBCMSLOGFILE'}="cvs.log";
+	$ENV{'CVS_RSH'} = "ssh" if ($scheme =~ /ssh/);
+} else {
+	die "cms $scheme unknown";
+}
+
+pb_log(1,"pb_vcs_init returns $scheme,$pbprojurl->{$ENV{'PBPROJ'}}\n");
+return($scheme,$pbprojurl->{$ENV{'PBPROJ'}});
+}
+
+
 =item B<pb_vcs_export>
 
 This function exports a VCS content to a directory.
@@ -116,13 +222,6 @@ if ($scheme =~ /^svn/) {
 	}
 } elsif ($scheme eq "dir") {
 	pb_system("cp -r $path $destdir","Copying $uri from DIR to $destdir ");
-} elsif (($scheme eq "http") || ($scheme eq "ftp")) {
-	my $f = basename($path);
-	unlink "$ENV{'PBTMP'}/$f";
-	pb_system("$vcscmd $ENV{'PBTMP'}/$f $uri","Downloading $uri with $vcscmd to $ENV{'PBTMP'}/$f\n");
-	# We want to preserve the original tar file
-	pb_vcs_export("file://$ENV{'PBTMP'}/$f",$source,$destdir);
-	return("$ENV{'PBTMP'}/$f");
 } elsif ($scheme =~ /^file/) {
 	eval
 	{
@@ -241,6 +340,13 @@ if ($scheme =~ /^svn/) {
 		$cvsopt = "-r $cvstag";
 	}
 	pb_system("cd $dir ; $vcscmd -d $account\@$host:$path export $cvsopt -d $base $tmp1","Exporting $tmp1 from $source under CVS to $destdir ");
+} elsif (($scheme =~ /http/) || ($scheme eq "ftp")) {
+	my $f = basename($path);
+	unlink "$ENV{'PBTMP'}/$f";
+	pb_system("$vcscmd $ENV{'PBTMP'}/$f $uri","Downloading $uri with $vcscmd to $ENV{'PBTMP'}/$f\n");
+	# We want to preserve the original tar file
+	pb_vcs_export("file://$ENV{'PBTMP'}/$f",$source,$destdir);
+	return("$ENV{'PBTMP'}/$f");
 } else {
 	confess "cms $scheme unknown";
 }
@@ -264,14 +370,20 @@ my $res = "";
 my $void = "";
 my $vcscmd = pb_vcs_cmd($scheme);
 
+pb_log(3,"scheme: $scheme - dir: $dir - vcscmd: $vcscmd\n");
 if ($scheme =~ /^svn/) {
 	open(PIPE,"LANGUAGE=C $vcscmd info $dir 2> /dev/null |") || return("");
 	while (<PIPE>) {
-		($void,$res) = split(/^URL:/) if (/^URL:/);
+		pb_log(4,"line: $_");
+		if (/^URL[\s]*:/) {
+			($void,$res) = split(/^URL[\s]*:/);
+			last;
+		}
 	}
 	$res =~ s/^\s*//;
 	close(PIPE);
 	chomp($res);
+	pb_log(3,"res $res\n");
 } elsif ($scheme =~ /^svk/) {
 	open(PIPE,"LANGUAGE=C $vcscmd info $dir 2> /dev/null |") || return("");
 	my $void2 = "";
@@ -295,7 +407,7 @@ if ($scheme =~ /^svn/) {
 		open(PIPE,"LANGUAGE=C $vcscmd info . 2> /dev/null |") || return("");
 		chdir($cwd) || return("");
 		while (<PIPE>) {
-			($void,$res) = split(/^URL:/) if (/^URL:/);
+			($void,$res) = split(/^URL[\s]*:/) if (/^URL[\s]*:/);
 		}
 		$res =~ s/^\s*//;
 		close(PIPE);
@@ -310,16 +422,24 @@ if ($scheme =~ /^svn/) {
 		} else {
 			# If not, the pbconf dir may be in the pbprojdir so sharing the .git dir
 			my $cwd = abs_path();
-			chdir($dir) || return("");;
+			chdir($ENV{'PBPROJDIR'}) || return("");;
 			open(GIT,"LANGUAGE=C $vcscmd remote -v 2> /dev/null |") || return("");
 			chdir($cwd) || return("");
 		}
+		my ($pborigin) = pb_conf_get("pbgitremote");
+		# Default git remote location called origin by default
+		$pborigin->{$ENV{'PBPROJ'}} = "origin" if ((not defined $pborigin) || (not defined $pborigin->{$ENV{'PBPROJ'}}));
 		while (<GIT>) {
-			next unless (/^origin\s+(\S+) \(push\)$/);
-			return $1;
+			next unless (/^$pborigin->{$ENV{'PBPROJ'}}\s+(\S+) \(push\)$/);
+			$res = $1;
+			if (($res =~ /@/) && ($res !~ /:\/\//)) {
+				# we have an ssh connection, return it
+				$res = "ssh://$res";
+			}
+			return $res;
 		}
 		close(GIT);
-		warn "Unable to find remote origin for $dir";
+		warn "Unable to find a remote git $pborigin->{$ENV{'PBPROJ'}} under $dir nor $ENV{'PBPROJDIR'}";
 		return "";
 	}
 } elsif ($scheme =~ /^cvs/) {
@@ -376,7 +496,7 @@ if ($scheme =~ /^svn/) {
 	$oldurl = pb_vcs_mod_htftp($oldurl,"svn");
 	$newurl = pb_vcs_mod_htftp($newurl,"svn");
 	pb_system("$vcscmd copy -m \"Creation of $newurl from $oldurl\" $oldurl $newurl","Copying $oldurl to $newurl ");
-} elsif ($scheme =~ /^(flat)|(ftp)|(http)|(file)\b/o) {
+} elsif ($scheme =~ /^(flat)|(ftp)|(http)|(https)|(file)\b/o) {
 	# Nothing to do.
 } else {
 	confess "cms $scheme unknown for project management";
@@ -411,7 +531,7 @@ if ($scheme =~ /^svn/) {
 } elsif ($scheme =~ /^git/) {
 	$url = pb_vcs_mod_htftp($url,"git");
 	pb_system("$vcscmd clone $url $destination","Checking out $url to $destination ");
-} elsif (($scheme eq "ftp") || ($scheme eq "http")) {
+} elsif (($scheme eq "ftp") || ($scheme =~ /http/)) {
 	return;
 } elsif ($scheme =~ /^cvs/) {
 	my ($scheme, $account, $host, $port, $path) = pb_get_uri($url);
@@ -455,7 +575,7 @@ if ($scheme =~ /^((svn)|(cvs)|(svk))/o) {
 	foreach my $d (@dir) {
 		pb_system("(cd $d && $vcscmd fetch)", "Updating $d ");
 	}
-} elsif ($scheme =~ /^(flat)|(ftp)|(http)|(file)\b/o) {
+} elsif ($scheme =~ /^(flat)|(ftp)|(http)|(https)|(file)\b/o) {
 	# Nothing to do.
 } else {
 	confess "cms $scheme unknown";
@@ -480,8 +600,8 @@ my $vcscmd = pb_vcs_cmd($scheme);
 if ($scheme =~ /^((svn)|(cvs)|(svk))/o) {
 	pb_system("cd $dir && $vcscmd ci -m \"$msg\" .","Checking in $dir ");
 } elsif ($scheme =~ /^git/) {
-	pb_system("cd $dir && $vcscmd commit -a -m \"$msg\"", "Checking in $dir ");
-} elsif ($scheme =~ /^(flat)|(ftp)|(http)|(file)\b/o) {
+	pb_system("cd $dir && git commit -m \"$msg\"", "Checking in $dir ");
+} elsif ($scheme =~ /^(flat)|(ftp)|(http)|(https)|(file)\b/o) {
 	# Nothing to do.
 } else {
 	confess "cms $scheme unknown";
@@ -491,7 +611,7 @@ pb_vcs_up($scheme,$dir);
 
 =item B<pb_vcs_add_if_not_in>
 
-This function adds to a VCS content from a local directory if the content wasn't already managed under th VCS.
+This function adds to a VCS content from a local directory if the content wasn't already managed under the VCS.
 The first parameter is the schema of the VCS systems (svn, cvs, svn+ssh, ...)
 The second parameter is a list of directory/file to add.
 
@@ -499,15 +619,16 @@ The second parameter is a list of directory/file to add.
 
 sub pb_vcs_add_if_not_in {
 my $scheme = shift;
-my @f = @_;
 my $vcscmd = pb_vcs_cmd($scheme);
 
 if ($scheme =~ /^((hg)|(git)|(svn)|(svk)|(cvs))/o) {
-	for my $f (@f) {
+	for my $f (@_) {
 		my $uri = pb_vcs_get_uri($scheme,$f);
-		pb_vcs_add($scheme,$f) if ($uri !~ /^$scheme/);
+		pb_log(3,"f: $f - scheme: $scheme - uri: $uri\n");
+		my ($scheme2, $a, $h, $p, $n) = pb_get_uri($uri);
+		pb_vcs_add($scheme,$f) if ("$scheme2" ne "$scheme");
 	}
-} elsif ($scheme =~ /^(flat)|(ftp)|(http)|(file)\b/o) {
+} elsif ($scheme =~ /^(flat)|(ftp)|(http)|(https)|(file)\b/o) {
 	# Nothing to do.
 } else {
 	confess "cms $scheme unknown";
@@ -528,13 +649,28 @@ my @f = @_;
 my $vcscmd = pb_vcs_cmd($scheme);
 
 if ($scheme =~ /^((hg)|(git)|(svn)|(svk)|(cvs))/o) {
-	pb_system("$vcscmd add ".join(' ',@f),"Adding ".join(' ',@f)." to VCS ");
-} elsif ($scheme =~ /^(flat)|(ftp)|(http)|(file)\b/o) {
+	$vcscmd =~ s/ svn// if (($scheme =~ /git/) && ($scheme =~ /svn/));
+	if ($scheme =~ /git/) {
+		# Here we need to be in the right place to add
+		for my $f (@f) {
+			my $dir = dirname($f);
+			pb_system("cd $dir ; $vcscmd add ".basename($f),"Adding $f to VCS ");
+		}
+	} else {
+		pb_system("$vcscmd add ".join(' ',@f),"Adding ".join(' ',@f)." to VCS ");
+	}
+} elsif ($scheme =~ /^(flat)|(ftp)|(http)|(https)|(file)\b/o) {
 	# Nothing to do.
 } else {
 	confess "cms $scheme unknown";
 }
-pb_vcs_up($scheme,@f);
+my @f1;
+foreach my $f (@f) {
+	push(@f1,$f) if (-d $f);
+	push(@f1,dirname($f)) if (-f $f);
+}
+# Wrong we need to push instead
+pb_vcs_up($scheme,@f1);
 }
 
 =item B<pb_vcs_isdiff>
@@ -552,6 +688,7 @@ my $vcscmd = pb_vcs_cmd($scheme);
 my $l = undef;
 
 if ($scheme =~ /^((svn)|(cvs)|(svk)|(git))/o) {
+	$vcscmd =~ s/ svn// if (($scheme =~ /git/) && ($scheme =~ /svn/));
 	open(PIPE,"$vcscmd diff $dir |") || confess "Unable to get $vcscmd diff from $dir";
 	$l = 0;
 	while (<PIPE>) {
@@ -559,7 +696,7 @@ if ($scheme =~ /^((svn)|(cvs)|(svk)|(git))/o) {
 		next if (/^cvs diff:/);
 		$l++;
 	}
-} elsif ($scheme =~ /^(flat)|(ftp)|(http)|(file)\b/o) {
+} elsif ($scheme =~ /^(flat)|(ftp)|(http)|(https)|(file)\b/o) {
 	$l = 0;
 } else {
 	confess "cms $scheme unknown";
@@ -638,15 +775,45 @@ pb_log(3,"pb_vcs_cmd returns $cmd\n");
 return($cmd);
 }
 
+=item B<pb_vcs_mkdir>
+
+This function makes a VCS directory
+The first parameter is the schema of the VCS systems (svn, cvs, svn+ssh, ...)
+The second parameter is the directory to create.
+The third parameter is the comment to pass during the commit
+
+=cut
+
+sub pb_vcs_mkdir {
+my $scheme = shift;
+my $dir = shift;
+my $msg = shift;
+my $vcscmd = pb_vcs_cmd($scheme);
+
+if ($scheme =~ /^((svn)|(cvs)|(svk))/o) {
+	pb_system("$vcscmd mkdir -m \"$msg\" $dir","Making VCS directory $dir");
+} elsif ($scheme =~ /^git/) {
+	#pb_system("cd $dir && git init ", "Making VCS directory $dir");
+	## + git remote add + git push
+} elsif ($scheme =~ /^(flat)|(ftp)|(http)|(https)|(file)\b/o) {
+	# Nothing to do.
+} else {
+	confess "cms $scheme unknown";
+}
+}
+
+
+
 =item B<pb_vcs_compliant>
 
 This function checks the compliance of the project and the pbconf directory.
 The first parameter is the key name of the value that needs to be read in the configuration file.
 The second parameter is the environment variable this key will populate.
 The third parameter is the location of the pbconf dir.
-The fourth parameter is the URI of the CMS content related to the pbconf dir.
+The fourth parameter is the URI of the VCS content related to the pbconf dir.
 The fifth parameter indicates whether we should inititate the context or not.
 
+Only called for PBCONFDIR and PBDIR
 =cut
 
 sub pb_vcs_compliant {
@@ -679,6 +846,7 @@ if ((defined $pdir) && (%pdir) && (defined $pdir{$ENV{'PBPROJ'}})) {
 # Expand potential env variable in it
 eval { $ENV{$envar} =~ s/(\$ENV.+\})/$1/eeg };
 pb_log(2,"$envar: $ENV{$envar}\n");
+my $exportdir = $ENV{$envar};
 
 my ($scheme, $account, $host, $port, $path) = pb_get_uri($uri);
 
@@ -686,20 +854,42 @@ if (($scheme !~ /^cvs/) && ($scheme !~ /^svn/) && ($scheme !~ /^svk/) && ($schem
 	# Do not compare if it's not a real cms
 	pb_log(1,"pb_vcs_compliant useless\n");
 	return;
-} elsif (defined $pbinit) {
-	pb_mkdir_p("$ENV{$envar}");
-} elsif (! -d "$ENV{$envar}") {
+} elsif ((defined $pbinit) && (! -d "$exportdir")) {
 	# Either we have a version in the uri, and it should be the same
 	# as the one in the envar. Or we should add the version to the uri
 	# But not if it's git as it manages version branches internally
-	if ((basename($uri) ne basename($ENV{$envar})) && ($scheme !~ /^git/)) {
-		$uri .= "/".basename($ENV{$envar})
+	if ((basename($uri) ne basename($exportdir)) && ($scheme !~ /git/)) {
+		$uri .= "/".basename($exportdir);
 	}
-	pb_log(1,"Checking out $uri\n");
-	# Create structure and remove end dir before exporting
-	pb_mkdir_p("$ENV{$envar}");
-	pb_rm_rf($ENV{$envar});
-	pb_vcs_checkout($scheme,$uri,$ENV{$envar});
+
+	pb_mkdir_p("$exportdir");
+	# Should only have pbconf
+	if ((pb_path_nbfiles(dirname($exportdir)) > 1) && ($envar eq 'PBCONFDIR')) {
+		confess("Directory ".dirname($exportdir)." has content.\nPlease remove it if you want to use that directory\n");
+	}
+	if (pb_path_nbfiles("$exportdir") > 0) {
+		confess("Directory $exportdir has content.\nPlease remove it if you want to use that directory\n");
+	}
+	if ($envar eq 'PBCONFDIR') {
+		# Remove the potential pbconf part if we treat pbconfdir
+		$exportdir =~ s|/pbconf[/]*||;
+		$uri =~ s|/pbconf[/]*||;
+	}
+	# Don't add content here as it may conflict later on with PBROOT addition
+	# Done in Env.pm 
+	pb_log(0,"Trying to check out (may fail) ".$uri."\n");
+	pb_vcs_checkout($scheme,$uri,$exportdir);
+	if (($envar eq 'PBCONFDIR') && (pb_path_nbfiles("$exportdir/pbconf") == 0)) {
+		# Export failed, because there is nothing yet in the repo
+		# we now need to clean stuff before doing mkdir to avoid conflicts
+		pb_rm_rf($exportdir);
+		pb_log(0,"Pushing first $uri\n");
+		pb_vcs_mkdir($scheme,$uri,"Creating structure directory");
+		pb_vcs_mkdir($scheme,"$uri/pbconf","Creating structure sub directory");
+		pb_log(0,"Re-Trying to check out again $uri\n");
+		pb_vcs_up($scheme,$exportdir);
+	}
+	pb_log(0,"Done\n");
 } else {
 	pb_log(1,"$uri found locally, checking content\n");
 	my $cmsurl = pb_vcs_get_uri($scheme,$ENV{$envar});
@@ -710,7 +900,7 @@ if (($scheme !~ /^cvs/) && ($scheme !~ /^svn/) && ($scheme !~ /^svk/) && ($schem
 	if ($scheme2 =~ /^git/) {
 		# remove schema from `git+file:` and `git+dir:` urls
 		# TODO: handle query-parameters
-		$uri =~ s/^git\+(file|dir|ssh):[\/]*//;
+		$uri =~ s/^git\+(file|dir):[\/]*//;
 		# Expand potential env variable in it -- this is required due to the consistency check
 		$uri =~ s/(\$ENV.+\})/$1/eeg;
 	} elsif ($scheme2 =~ /^hg/) {
@@ -732,9 +922,27 @@ if (($scheme !~ /^cvs/) && ($scheme !~ /^svn/) && ($scheme !~ /^svk/) && ($schem
 		# they match - do nothing - there may be local changes
 	}
 }
-pb_log(1,"pb_vcs_compliant end\n");
+pb_log(2,"pb_vcs_compliant end\n");
 }
 
+=item B<pb_vcs_conf_update_v0>
+
+This function transform the old configuration v0 file as first param into a new v1 one as second param  by calling a COnf.pm function and then adds the resulting file into VCS
+
+=cut
+
+
+sub pb_vcs_conf_update_v0 {
+
+my $orig = shift;
+my $dest = shift;
+
+pb_conf_update_v0($orig,$dest);
+# Adding this new file to VCS (not removing the previous one)
+my ($pbprojurl) = pb_conf_get("pbprojurl");
+my ($scheme, $account, $host, $port, $path) = pb_get_uri($pbprojurl->{$ENV{'PBPROJ'}});
+pb_vcs_add_if_not_in($scheme,$dest);
+}
 
 =back 
 
