@@ -2,7 +2,7 @@
 #
 # Common functions for virtual environment
 # 
-# Copyright B. Cornec 2007-2016
+# Copyright B. Cornec 2007-today
 # Eric Anderson's changes are (c) Copyright 2012 Hewlett Packard
 # Provided under the GPL v2
 #
@@ -33,7 +33,7 @@ use Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT = qw(pb_ve_launch pb_ve_snap pb_ve_get_type pb_ve_docker_repo pb_ve_docker_get_image);
 
-($VERSION,$REVISION) = pb_version_init();
+our ($VERSION,$REVISION,$PBCONFVER) = pb_version_init();
 
 =pod
 
@@ -67,14 +67,14 @@ This function launches a VE, creating it if necessary using multiple external po
 sub pb_ve_launch {
 
 my $v = shift;
-my $pbforce = shift;			# Which step are we in (0: create, 1: setup, 2: build, 3: use)
+my $pbstep = shift;			# Which step are we in (0: create, 1: setup, 2: build, 3: use)
 my $locsnap = shift;
 my $vetype = shift;
 my $pbimage = shift;
 
 my $docrepo = "";			# By default no repository for docker available
 
-pb_log(2,"Entering pb_ve_launch at step $pbforce for type $vetype\n");
+pb_log(2,"Entering pb_ve_launch at step $pbstep for type $vetype\n");
 # Get distro context
 my $pbos = pb_distro_get_context($v);
 
@@ -95,7 +95,7 @@ if ($arch ne $pbos->{'arch'}) {
 my $sudocmd="";
 if ($EFFECTIVE_USER_ID != 0) {
 	$sudocmd ="sudo ";
-	foreach my $proxy (qw/http_proxy ftp_proxy/) {
+	foreach my $proxy (qw/http_proxy https_proxy ftp_proxy/) {
 		if (defined $ENV{$proxy}) {
 			open(CMD,"sudo sh -c 'echo \$$proxy' |") or die "can't run sudo sh?: $!";
 			$_ = <CMD>;
@@ -109,7 +109,8 @@ if ($EFFECTIVE_USER_ID != 0) {
 # Handle cross arch on Intel based platforms
 $sudocmd = "setarch i386 $sudocmd" if (($pbos->{'arch'} =~ /i[3456]86/) && ($arch eq 'x86_64'));
 
-my $root = pb_path_expand($vepath->{$ENV{PBPROJ}});
+confess "No vepath value defined, please add one to your project yml file" if ((not defined $vepath) or (not defined $vepath->{$ENV{'PBPROJ'}})); 
+my $root = pb_path_expand($vepath->{$ENV{'PBPROJ'}});
 	
 if (($vetype eq "chroot") || ($vetype eq "schroot") || ($vetype eq "docker")) {
 
@@ -117,11 +118,11 @@ if (($vetype eq "chroot") || ($vetype eq "schroot") || ($vetype eq "docker")) {
 	umask 0022;
 
 	# We can probably only get those params now we have the distro context
-	my ($rbsb4pi,$rbspi,$vesnap,$oscodename,$osmindep,$verebuild,$rbsmirrorsrv) = pb_conf_get_if("rbsb4pi","rbspi","vesnap","oscodename","osmindep","verebuild","rbsmirrorsrv");
+	my ($vesnap,$verebuild) = pb_conf_get_if("vesnap","verebuild");
 
-	if (((((defined $verebuild) && ($verebuild->{$ENV{'PBPROJ'}} =~ /true/i)) || ($pbforce == 0)) && ($vetype ne "docker"))
+	if (((((defined $verebuild) && (defined $verebuild->{$ENV{'PBPROJ'}}) && ($verebuild->{$ENV{'PBPROJ'}} =~ /true/i)) || ($pbstep == 0)) && ($vetype ne "docker"))
 		# For docker we may have a reference image that we'll use
-		|| (($vetype eq "docker") && ($pbforce == 0) && ((not defined $pbimage) || ($pbimage eq "")))) {
+		|| (($vetype eq "docker") && ($pbstep == 0) && ((not defined $pbimage) || ($pbimage eq "")))) {
 
 		my ($verpmtype,$vedebtype) = pb_conf_get("verpmtype","vedebtype");
 		my ($rbsopt1) = pb_conf_get_if("rbsopt");
@@ -131,7 +132,7 @@ if (($vetype eq "chroot") || ($vetype eq "schroot") || ($vetype eq "docker")) {
 	
 			# Which tool is used
 			my $verpmstyle = $verpmtype->{$ENV{'PBPROJ'}};
-			die "No verpmtype defined for $ENV{PBPROJ}" unless (defined $verpmstyle);
+			die "No verpmtype defined for $ENV{'PBPROJ'}" unless (defined $verpmstyle);
 	
 			# Get potential rbs option
 			my $rbsopt = "";
@@ -145,11 +146,11 @@ if (($vetype eq "chroot") || ($vetype eq "schroot") || ($vetype eq "docker")) {
 				}
 			}
 	
-			my $postinstall = pb_ve_get_postinstall($pbos,$rbspi,$verpmstyle);
+			my $postinstall = pb_ve_get_postinstall($pbos,$verpmstyle);
 			if ($verpmstyle eq "rinse") {
 				# Need to reshape the mirrors generated with local before-post-install script
 				my $b4post = "--before-post-install ";
-				my $postparam = pb_distro_get_param($pbos,$rbsb4pi);
+				my $postparam = pb_distro_get_if($pbos,"rbsb4pi");
 				if ($postparam eq "") {
 					$b4post = "";
 				} else {
@@ -159,7 +160,7 @@ if (($vetype eq "chroot") || ($vetype eq "schroot") || ($vetype eq "docker")) {
 				# Need to reshape the package list for pb
 				my $addpkgs;
 				$postparam = "";
-				$postparam .= pb_distro_get_param($pbos,$osmindep);
+				$postparam .= pb_distro_get_if($pbos,"osmindep");
 				if ($postparam eq "") {
 					$addpkgs = "";
 				} else {
@@ -185,7 +186,7 @@ if (($vetype eq "chroot") || ($vetype eq "schroot") || ($vetype eq "docker")) {
 				}
 				my $addpkgs = "";
 				my $postparam = "";
-				$postparam .= pb_distro_get_param($pbos,$osmindep);
+				$postparam .= pb_distro_get_if($pbos,"osmindep");
 				if ($postparam eq "") {
 					$addpkgs = "";
 				} else {
@@ -206,17 +207,17 @@ if (($vetype eq "chroot") || ($vetype eq "schroot") || ($vetype eq "docker")) {
 		} elsif ($pbos->{'type'} eq "deb") {
 			my $vedebstyle = $vedebtype->{$ENV{'PBPROJ'}};
 		
-			my $codename = pb_distro_get_param($pbos,$oscodename);
+			my $codename = pb_distro_get_if($pbos,"oscodename");
 			my $postparam = "";
 			my $addpkgs;
-			$postparam .= pb_distro_get_param($pbos,$osmindep);
+			$postparam .= pb_distro_get_if($pbos,"osmindep");
 			if ($postparam eq "") {
 				$addpkgs = "";
 			} else {
 				$addpkgs = "--include $postparam";
 			}
 			my $debmir = "";
-			$debmir .= pb_distro_get_param($pbos,$rbsmirrorsrv);
+			$debmir .= pb_distro_get_if($pbos,"rbsmirrorsrv");
 	
 			# Get potential rbs option
 			my $rbsopt = "";
@@ -253,6 +254,8 @@ if (($vetype eq "chroot") || ($vetype eq "schroot") || ($vetype eq "docker")) {
 			}
 		} elsif ($pbos->{'type'} eq "ebuild") {
 			die "Please teach the dev team how to build gentoo chroot";
+		} elsif ($pbos->{'type'} eq "apk") {
+			die "Please teach the dev team how to build alpine chroot";
 		} else {
 			die "Unknown distribution type $pbos->{'type'}. Report to dev team";
 		}
@@ -279,7 +282,7 @@ if (($vetype eq "chroot") || ($vetype eq "schroot") || ($vetype eq "docker")) {
 	}
 
 	# If docker, create the image and remove the now temp dir except if we had one already
-	if (($vetype eq "docker") && ($pbforce == 0)) {
+	if (($vetype eq "docker") && ($pbstep == 0)) {
 		my $cmd1 = pb_check_req("docker",0);
 		# step 0 : nothing at creation -> tag n-v-a (made below)
 
@@ -298,15 +301,15 @@ if (($vetype eq "chroot") || ($vetype eq "schroot") || ($vetype eq "docker")) {
 			# That container should then be setup correctly which may not be the case yet
 			#
 			# We can probably only get those params now we have the distro context
-			my ($osmindep) = pb_conf_get_if("osmindep");
-			my $pkgs = pb_distro_get_param($pbos,$osmindep);
+			my $pkgs = pb_distro_get_if($pbos,"osmindep");
 			$pkgs =~ s/,/ /g;
 			my $tmpd = "$ENV{'PBTMP'}/Dockerfile";
 			open(DOCKER, "> $tmpd") || die "Unable to create the docker file $tmpd";
 			print DOCKER "FROM $pbimage\n";
 			print DOCKER "MAINTAINER project-builder.org aka pb\n";
-			print DIOCKER "ENV ftp_proxy $ENV{ftp_proxy}\n" if (defined $ENV{ftp_proxy});
-			print DIOCKER "ENV http_proxy $ENV{http_proxy}\n" if (defined $ENV{http_proxy});
+			print DOCKER "ENV ftp_proxy $ENV{'ftp_proxy'}\n" if (defined $ENV{'ftp_proxy'});
+			print DOCKER "ENV http_proxy $ENV{'http_proxy'}\n" if (defined $ENV{'http_proxy'});
+			print DOCKER "ENV https_proxy $ENV{'https_proxy'}\n" if (defined $ENV{'https_proxy'});
 			# We are root in that container so no need to sudo, which is present potentially
 			my $cmd2 = $pbos->{'install'};
 			$cmd2 =~ s/sudo //g;
@@ -330,7 +333,6 @@ if (($vetype eq "chroot") || ($vetype eq "schroot") || ($vetype eq "docker")) {
 sub pb_ve_get_postinstall {
 
 my $pbos = shift;
-my $rbspi = shift;
 my $vestyle = shift;
 my $post = "";
 
@@ -341,7 +343,7 @@ if ($vestyle eq "rinse") {
 	$post = "-s ";
 }
 
-my $postparam = pb_distro_get_param($pbos,$rbspi);
+my $postparam = pb_distro_get_if($pbos,"rbspi");
 if ($postparam eq "") {
 	$post = "";
 } else {
@@ -383,7 +385,7 @@ return($docreg);
 sub pb_ve_docker_get_image {
 
 my $pbimage = shift;
-my $found = 0;
+my $found =undef;
 
 die "Unable to handle an undef docker image" if (not defined $pbimage);
 
@@ -408,8 +410,8 @@ if (not defined $vetype) {
 	my ($ptr) = pb_conf_get("vetype");
 	$vetype = $ptr->{$ENV{'PBPROJ'}};
 }
-confess "No vetype defined for $ENV{PBPROJ}" unless (defined $vetype);
-pb_log(1, "Using vetype $vetype for $ENV{PBPROJ}\n");
+confess "No vetype defined for $ENV{'PBPROJ'}" unless (defined $vetype);
+pb_log(1, "Using vetype $vetype for $ENV{'PBPROJ'}\n");
 return($vetype);
 }
 
