@@ -4,7 +4,7 @@
 # Those are filtered with pb mecanism
 # and have been isolated here to avoid unrelated effects
 #
-# Copyright B. Cornec 2007-2016
+# Copyright B. Cornec 2007-today
 # Provided under the GPL v2
 #
 package ProjectBuilder::Version;
@@ -13,22 +13,25 @@ use strict;
 
 # Inherit from the "Exporter" module which handles exporting functions.
  
-use vars qw($VERSION $REVISION @ISA @EXPORT);
+use vars qw($VERSION $REVISION $PBCONFVER @ISA @EXPORT);
 use Exporter;
  
 # Export, by default, all the functions into the namespace of
 # any code which uses this module.
 our @ISA = qw(Exporter);
-our @EXPORT = qw(pb_version_init);
+our @EXPORT = qw(pb_version_init $PBCONFVER);
 
-$VERSION = "0.14.1"."";
-$REVISION = "2128";
+$VERSION = "0.16.2"."";
+$REVISION = "2692";
+# We fix the format of the conf file for this version of pb
+$PBCONFVER = 1;
 
 sub pb_version_init {
 
 my $projectbuilderver = $VERSION;
 my $projectbuilderrev = $REVISION;
+my $projectbuilderconfver = $PBCONFVER;
 
-return($projectbuilderver,$projectbuilderrev);
+return($projectbuilderver,$projectbuilderrev,$projectbuilderconfver);
 }
 1;
